==> ZenTaoPMS.max3.1.php7.0.zip: zentaopms/extension/max/user/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPoL/dDhwn6GTDyi9+Qj4nMf5nMvJ0y7MX+51OisNmeyuTP84HceRqfR5XGOBxuywCAculs3V
m/QPi7RTl7ad/6Zdg3MgJOQKoMRQ5cfOYEz1jt1odhz4rqvV0icRofqKWLcB6XcCb+ZRgjC381fS
LpvpPcCpc7TzgUXryasJu6ggMgNDaaXH6tm+FMflFyX2XW8lGUNlFqdD+rP9phtZ7iWjfH3WTmTC
My3FfroHJuf3fu7ujTKwdHhMWgR+Z8NB4OXM94eEjmKNRc+eoh6Rj2Tqg+thX12DzylPstNEZlWd
lbS437ZttDFUH07zDmxf8NiHgbR+vGRFf5oR/omZWIoH6jVoWfhdNsLpA/ErXPNj95aDLlP0EUg3
yu/bZx4AJHhkCm8Kz+pYbeuRfUXGj7bAgJvKVN8xQYfivjzu3w4fY6/tBSQvvbfylRLkaFV/sbdM
Va9ALAM7NpH4ve0TVZshkiQA8GMw+KT01GzJIfpGymtM4IWJVGXrXRgs/owKPbRkE7+1OWLTCI7Q
Y3vYqH7FMF34Gfex0o8Wcqi6yzHPxRlhxFjnu0tm1K2tKibwnbAxJdWL1KoBVWI8e5CRtJhw2xeb
Wulu0pTCsizcTGrSKArALTJ71nIePwXZDNgbCK7GFqry4ib3vaoHthHO1l9yivTK84/aZNgCGTnT
l5ykPGdl1StnfuQQi034IfbNHkNcHKGEyudayfXDoUKHWef/erfnDTa=

==> ZenTaoPMS.max3.4.php7.2_7.4.zip: zentaopms/extension/max/user/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPzS1OybYxbVlpxNswgO/8xk1jtjqXz4pZyP/0R2y9HLccdLuV1EisAyHwhGEysFi4Sh5bvtO
4yYSK9ewYQItL5BXdiRgsuBxBAkEUUdXwgsqypwzD3WXIhEFWYLgtLJ/DIRf8JdDxGpodh0mh1P0
mXJjGAx60Gp2mRuO/Y1lh5clFm4hL+x5BYS7ZlxDTUCicamV8+r/kmhRWivm+DIzzNWSmoiwu6oz
5MsC1fTB21X/y3kahatoiaKoL5S7R76xUJ1WYAijWDZlUiZRbQO1e+xOKYu4NRqSCiOkVD7NSOpO
Mi/Tigdow5XxHuMj60r6sC0KvTxarKpLzR4GdH9SKn/h96i7UoaKAD+Ekh4RzRkbFM7O0xigmnnQ
kjf2dk8Md9gCQyLu4y220PdKcZehT+QnDi0LMahnlXxX6MKp0mSum8Wx1IRFSeAKdGkRk+X8Ujbl
L7hcYYg6/n6zRmDAk+nLAQzQsclaLH7AVgfoW5+pYQJAC+e3xsrmvIFw+lJUAqbpS7AoITkh1G+E
fw40vUS159kL8lLMZVsUab+nPnCLpx5u0tdjVkbazzZdpgC8piuOHOLdCVhrLOmgAPgWkeCumvai
hzaxk+RyMPpH3G3jUSzEN1pZIlFC8AUh7qlx4/GhWnXZDP+oAToFlFpPaKZn0m2dyC50evfoxouC
5rbxqSOp1xyrE9Gu/2TOA1Ee6VFzeK21Cecvyi1Dl95oEeK=
